@@ -34,13 +34,13 @@ from tempfile import mkstemp
 
 import add
 
-log = logging.getLogger("Griffith")
-
 import db
 import edit
 
 from gi.repository import Gtk
 
+log = logging.getLogger("Griffith")
+
 # detect all plugins:
 __all__ = [os.path.basename(x)[:-3]
            for x in glob.glob("%s/*.py" % os.path.dirname(__file__))]
@@ -337,7 +337,7 @@ class ImportPlugin(object):
         self.tagmap = {}
         for tag in self.db.session.query(db.Tag.tag_id, db.Tag.name).all():
             tagname = self.normalizename(tag.name)
-            if not tagname in self.tagmap:
+            if tagname not in self.tagmap:
                 self.tagmap[tagname] = tag.tag_id
 
     def _loadmappingmedium(self):
@@ -345,7 +345,7 @@ class ImportPlugin(object):
         for medium in self.db.session.query(db.Medium.medium_id,
                                             db.Medium.name).all():
             mediumname = self.normalizename(medium.name)
-            if not mediumname in mediummap:
+            if mediumname not in mediummap:
                 mediummap[mediumname] = medium.medium_id
         return mediummap
 
@@ -354,7 +354,7 @@ class ImportPlugin(object):
         for vcodec in self.db.session.query(db.VCodec.vcodec_id,
                                             db.VCodec.name).all():
             vcodecname = self.normalizename(vcodec.name)
-            if not vcodecname in vcodecsmap:
+            if vcodecname not in vcodecsmap:
                 vcodecsmap[vcodecname] = vcodec.vcodec_id
         return vcodecsmap
 
@@ -363,7 +363,7 @@ class ImportPlugin(object):
         for collection in self.db.session.query(db.Collection.collection_id,
                                                 db.Collection.name).all():
             collectionname = self.normalizename(collection.name)
-            if not collectionname in collectionsmap:
+            if collectionname not in collectionsmap:
                 collectionsmap[collectionname] = collection.collection_id
         return collectionsmap
 
@@ -372,7 +372,7 @@ class ImportPlugin(object):
         for volume in self.db.session.query(db.Volume.volume_id,
                                             db.Volume.name).all():
             volumename = self.normalizename(volume.name)
-            if not volumename in volumesmap:
+            if volumename not in volumesmap:
                 volumesmap[volumename] = volume.volume_id
         return volumesmap
 
